query: yfinQuery

Description Usage Examples

Description

Run a query against the API. This function is used as the base query for all other functions in this package, or you can input your own custom path

Usage

1
yfinQuery(path)

Examples

1
yfinQuery('/v8/finance/chart/AAPL')

stevensolarz/rYahooFinance documentation built on Jan. 8, 2022, 7:44 p.m.