yfinQuery: Run a query against the API. This function is used as the...

Description Usage Arguments Value

View source: R/query.R

Description

Run a query against the API. This function is used as the base query for all other functions in this package, or you can input your own custom path

Usage

1
yfinQuery(path)

Arguments

path

The path of the query.

Value

Result of the query


stevensolarz/rYahooFinance documentation built on Jan. 8, 2022, 7:44 p.m.