Run a query against the API. This function is used as the base query for all other functions in this package, or you can input your own custom path
1 | yfinQuery(path)
|
1 | yfinQuery('/v8/finance/chart/AAPL')
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.